lilypondfiletools.LilyPondDimension
===================================

.. abjad-lineage:: abjad.tools.lilypondfiletools.LilyPondDimension.LilyPondDimension.LilyPondDimension

.. autoclass:: abjad.tools.lilypondfiletools.LilyPondDimension.LilyPondDimension.LilyPondDimension

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.lilypondfiletools.LilyPondDimension.LilyPondDimension.LilyPondDimension.lilypond_format
      ~abjad.tools.lilypondfiletools.LilyPondDimension.LilyPondDimension.LilyPondDimension.unit
      ~abjad.tools.lilypondfiletools.LilyPondDimension.LilyPondDimension.LilyPondDimension.value
      ~abjad.tools.lilypondfiletools.LilyPondDimension.LilyPondDimension.LilyPondDimension.__eq__
      ~abjad.tools.lilypondfiletools.LilyPondDimension.LilyPondDimension.LilyPondDimension.__ne__
      ~abjad.tools.lilypondfiletools.LilyPondDimension.LilyPondDimension.LilyPondDimension.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.lilypondfiletools.LilyPondDimension.LilyPondDimension.LilyPondDimension.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.lilypondfiletools.LilyPondDimension.LilyPondDimension.LilyPondDimension.unit
   :noindex:

.. autoattribute:: abjad.tools.lilypondfiletools.LilyPondDimension.LilyPondDimension.LilyPondDimension.value
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.lilypondfiletools.LilyPondDimension.LilyPondDimension.LilyPondDimension.__eq__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LilyPondDimension.LilyPondDimension.LilyPondDimension.__ne__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LilyPondDimension.LilyPondDimension.LilyPondDimension.__repr__
   :noindex:
